@@ -1,7 +1,8 @@
 """Visa instrument driver based on pyvisa."""
-from typing import Sequence, Optional, Dict, Union, Any
+from typing import Sequence, Optional, Dict, Union, Any, cast
 import warnings
 import logging
+from packaging.version import Version
 
 import pyvisa as visa
 import pyvisa.constants as vi_const
@@ -14,6 +15,8 @@ from qcodes.utils.deprecate import deprecate
 from qcodes.logger.instrument_logger import get_instrument_logger
 from qcodes.utils.delaykeyboardinterrupt import DelayedKeyboardInterrupt
 
+pyvisa_is_1_11_or_higher = Version(pyvisa.__version__) >= Version('1.11.0')
+
 VISA_LOGGER = '.'.join((InstrumentBase.__module__, 'com', 'visa'))
 
 log = logging.getLogger(__name__)
@@ -120,11 +123,11 @@ class VisaInstrument(Instrument):
             self.visabackend = 'ni'
 
         self.visa_log.info(f'Opening PyVISA resource at address: {address}')
-        resouce = resource_manager.open_resource(address)
-        if not isinstance(resouce, visa.resources.MessageBasedResource):
+        resource = resource_manager.open_resource(address)
+        if not isinstance(resource, visa.resources.MessageBasedResource):
             raise TypeError("QCoDeS only support MessageBasedResource "
                             "Visa resources")
-        self.visa_handle = resouce
+        self.visa_handle = resource
         self._address = address
 
     def device_clear(self) -> None:
@@ -139,10 +142,20 @@ class VisaInstrument(Instrument):
         if self.visabackend == 'sim':
             return
 
-        if isinstance(self.visa_handle, pyvisa.resources.SerialInstrument):
-            self.visa_handle.flush(
-                vi_const.BufferOperation.discard_read_buffer_no_io | vi_const.BufferOperation.discard_write_buffer
+        if pyvisa_is_1_11_or_higher:
+            flush_operation = (
+                    vi_const.BufferOperation.discard_read_buffer_no_io |
+                    vi_const.BufferOperation.discard_write_buffer
             )
+        else:
+            # This can be dropped once we drop support for pyvisa 1.10
+            flush_operation = cast(
+                Any,
+                vi_const.VI_READ_BUF_DISCARD | vi_const.VI_WRITE_BUF_DISCARD
+            )
+
+        if isinstance(self.visa_handle, pyvisa.resources.SerialInstrument):
+            self.visa_handle.flush(flush_operation)
         else:
             self.visa_handle.clear()
 
