@@ -1,10 +1,11 @@
 from distutils.version import LooseVersion
+from typing import Any
 
 import numpy as np
 
-from qcodes.utils import validators
 from qcodes.instrument_drivers.AlazarTech.ATS import AlazarTech_ATS
 from qcodes.instrument_drivers.AlazarTech.utils import TraceParameter
+from qcodes.utils import validators
 
 
 class AlazarTech_ATS9373(AlazarTech_ATS):
@@ -23,8 +24,9 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
     samples_divisor = 128
     _trigger_holdoff_min_fw_version = '30.04'
 
-    def __init__(self, name, **kwargs):
-        dll_path = 'C:\\WINDOWS\\System32\\ATSApi.dll'
+    def __init__(self, name: str,
+                 dll_path: str = 'C:\\WINDOWS\\System32\\ATSApi.dll',
+                 **kwargs: Any):
         super().__init__(name, dll_path=dll_path, **kwargs)
 
         # add parameters
@@ -32,15 +34,13 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         # ----- Parameters for the configuration of the board -----
         self.add_parameter(name='clock_source',
                            parameter_class=TraceParameter,
-                           get_cmd=None,
                            label='Clock Source',
                            unit=None,
                            initial_value='INTERNAL_CLOCK',
                            val_mapping={'INTERNAL_CLOCK': 1,
-                                       'FAST_EXTERNAL_CLOCK': 2,
-                                       'EXTERNAL_CLOCK_10MHz_REF': 7})
+                                        'FAST_EXTERNAL_CLOCK': 2,
+                                        'EXTERNAL_CLOCK_10MHz_REF': 7})
         self.add_parameter(name='external_sample_rate',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='External Sample Rate',
                            unit='S/s',
@@ -48,7 +48,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                                                      validators.Enum('UNDEFINED')),
                            initial_value='UNDEFINED')
         self.add_parameter(name='sample_rate',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Internal Sample Rate',
                            unit='S/s',
@@ -89,7 +88,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                              'EXTERNAL_CLOCK': 64,
                                   'UNDEFINED': 'UNDEFINED'})
         self.add_parameter(name='clock_edge',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Clock Edge',
                            unit=None,
@@ -97,47 +95,41 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                            val_mapping={'CLOCK_EDGE_RISING': 0,
                                         'CLOCK_EDGE_FALLING': 1})
         self.add_parameter(name='decimation',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Decimation',
                            unit=None,
                            initial_value=1,
                            vals=validators.Ints(0, 100000))
 
-        for i in ['1', '2']:
-            self.add_parameter(name='coupling' + i,
-                               get_cmd=None,
+        for i in range(1, self.channels+1):
+            self.add_parameter(name=f'coupling{i}',
                                parameter_class=TraceParameter,
-                               label='Coupling channel ' + i,
+                               label=f'Coupling channel {i}',
                                unit=None,
                                initial_value='DC',
                                val_mapping={'AC': 1, 'DC': 2})
-            self.add_parameter(name='channel_range' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'channel_range{i}',
                                parameter_class=TraceParameter,
-                               label='Range channel ' + i,
+                               label=f'Range channel {i}',
                                unit='V',
                                initial_value=0.4,
                                val_mapping={0.4: 7})
-            self.add_parameter(name='impedance' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'impedance{i}',
                                parameter_class=TraceParameter,
-                               label='Impedance channel ' + i,
+                               label=f'Impedance channel {i}',
                                unit='Ohm',
                                initial_value=50,
                                val_mapping={50: 2})
 
-            self.add_parameter(name='bwlimit' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'bwlimit{i}',
                                parameter_class=TraceParameter,
-                               label='Bandwidth limit channel ' + i,
+                               label=f'Bandwidth limit channel {i}',
                                unit=None,
                                initial_value='DISABLED',
                                val_mapping={'DISABLED': 0,
                                             'ENABLED': 1})
 
         self.add_parameter(name='trigger_operation',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Trigger Operation',
                            unit=None,
@@ -149,57 +141,52 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                                         'TRIG_ENGINE_OP_J_XOR_K': 4,
                                         'TRIG_ENGINE_OP_J_AND_NOT_K': 5,
                                         'TRIG_ENGINE_OP_NOT_J_AND_K': 6})
-        for i in ['1', '2']:
-            self.add_parameter(name='trigger_engine' + i,
-                               get_cmd=None,
+        n_trigger_engines = 2
+
+        for i in range(1, n_trigger_engines+1):
+            self.add_parameter(name=f'trigger_engine{i}',
                                parameter_class=TraceParameter,
-                               label='Trigger Engine ' + i,
+                               label=f'Trigger Engine {i}',
                                unit=None,
-                               initial_value='TRIG_ENGINE_' + ('J' if i == '1' else 'K'),
+                               initial_value='TRIG_ENGINE_' + ('J' if i == 1 else 'K'),
                                val_mapping={'TRIG_ENGINE_J': 0,
                                             'TRIG_ENGINE_K': 1})
-            self.add_parameter(name='trigger_source' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'trigger_source{i}',
                                parameter_class=TraceParameter,
-                               label='Trigger Source ' + i,
+                               label=f'Trigger Source {i}',
                                unit=None,
                                initial_value='EXTERNAL',
                                val_mapping={'CHANNEL_A': 0,
                                             'CHANNEL_B': 1,
                                             'EXTERNAL': 2,
                                             'DISABLE': 3})
-            self.add_parameter(name='trigger_slope' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'trigger_slope{i}',
                                parameter_class=TraceParameter,
-                               label='Trigger Slope ' + i,
+                               label=f'Trigger Slope {i}',
                                unit=None,
                                initial_value='TRIG_SLOPE_POSITIVE',
                                val_mapping={'TRIG_SLOPE_POSITIVE': 1,
                                             'TRIG_SLOPE_NEGATIVE': 2})
-            self.add_parameter(name='trigger_level' + i,
-                               get_cmd=None,
+            self.add_parameter(name=f'trigger_level{i}',
                                parameter_class=TraceParameter,
-                               label='Trigger Level ' + i,
+                               label=f'Trigger Level {i}',
                                unit=None,
                                initial_value=140,
                                vals=validators.Ints(0, 255))
 
         self.add_parameter(name='external_trigger_coupling',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='External Trigger Coupling',
                            unit=None,
                            initial_value='DC',
-                           val_mapping={'AC': 1,'DC': 2})
+                           val_mapping={'AC': 1, 'DC': 2})
         self.add_parameter(name='external_trigger_range',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='External Trigger Range',
                            unit=None,
                            initial_value='ETR_2V5',
                            val_mapping={'ETR_TTL': 2, 'ETR_2V5': 3})
         self.add_parameter(name='trigger_delay',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Trigger Delay',
                            unit='Sample clock cycles',
@@ -218,7 +205,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         # the board may trigger if the timeout interval expires before a
         # hardware trigger event arrives.
         self.add_parameter(name='timeout_ticks',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='Timeout Ticks',
                            unit='10 us',
@@ -226,7 +212,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                            vals=validators.Ints(min_value=0))
 
         self.add_parameter(name='aux_io_mode',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='AUX I/O Mode',
                            unit=None,
@@ -235,7 +220,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                                         'AUX_IN_TRIGGER_ENABLE': 1,
                                         'AUX_IN_AUXILIARY': 13})
         self.add_parameter(name='aux_io_param',
-                           get_cmd=None,
                            parameter_class=TraceParameter,
                            label='AUX I/O Param',
                            unit=None,
@@ -249,14 +233,12 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                            label='Acquisition mode',
                            unit=None,
                            initial_value='NPT',
-                           get_cmd=None,
                            set_cmd=None,
                            val_mapping={'NPT': 0x200, 'TS': 0x400})
         self.add_parameter(name='samples_per_record',
                            label='Samples per Record',
                            unit=None,
                            initial_value=1024,
-                           get_cmd=None,
                            set_cmd=None,
                            vals=validators.Multiples(
                                 divisor=self.samples_divisor, min_value=256))
@@ -264,34 +246,29 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                            label='Records per Buffer',
                            unit=None,
                            initial_value=10,
-                           get_cmd=None,
                            set_cmd=None,
                            vals=validators.Ints(min_value=0))
         self.add_parameter(name='buffers_per_acquisition',
                            label='Buffers per Acquisition',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value=10,
                            vals=validators.Ints(min_value=0))
         self.add_parameter(name='channel_selection',
                            label='Channel Selection',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='AB',
                            val_mapping={'A': 1, 'B': 2, 'AB': 3})
         self.add_parameter(name='transfer_offset',
                            label='Transfer Offset',
                            unit='Samples',
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value=0,
                            vals=validators.Ints(min_value=0))
         self.add_parameter(name='external_startcapture',
                            label='External Startcapture',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='ENABLED',
                            val_mapping={'DISABLED': 0X0,
@@ -299,7 +276,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='enable_record_headers',
                            label='Enable Record Headers',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='DISABLED',
                            val_mapping={'DISABLED': 0x0,
@@ -307,7 +283,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='alloc_buffers',
                            label='Alloc Buffers',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='DISABLED',
                            val_mapping={'DISABLED': 0x0,
@@ -315,7 +290,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='fifo_only_streaming',
                            label='Fifo Only Streaming',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='DISABLED',
                            val_mapping={'DISABLED': 0x0,
@@ -323,7 +297,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='interleave_samples',
                            label='Interleave Samples',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='DISABLED',
                            val_mapping={'DISABLED': 0x0,
@@ -331,7 +304,6 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='get_processed_data',
                            label='Get Processed Data',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value='DISABLED',
                            val_mapping={'DISABLED': 0x0,
@@ -339,14 +311,12 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         self.add_parameter(name='allocated_buffers',
                            label='Allocated Buffers',
                            unit=None,
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value=4,
                            vals=validators.Ints(min_value=0))
         self.add_parameter(name='buffer_timeout',
                            label='Buffer Timeout',
                            unit='ms',
-                           get_cmd=None,
                            set_cmd=None,
                            initial_value=1000,
                            vals=validators.Ints(min_value=0))
@@ -366,8 +336,8 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
 
         model = self.get_idn()['model']
         if model != 'ATS9373':
-            raise Exception("The Alazar board kind is not 'ATS9373',"
-                            " found '" + str(model) + "' instead.")
+            raise Exception(f"The Alazar board kind is not 'ATS9373',"
+                            f" found '{str(model)}' instead.")
 
     def _get_trigger_holdoff(self) -> bool:
         fwversion = self.get_idn()['firmware']
