@@ -1,4 +1,3 @@
-
 import time
 from math import floor
 
@@ -15,11 +14,6 @@ from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.data_export import get_data_by_id
 from qcodes.dataset.sqlite.queries import get_guids_from_run_spec
 from qcodes.dataset.experiment_container import new_experiment
-# pylint: disable=unused-import
-from qcodes.tests.dataset.temporary_databases import (empty_temp_db,
-                                                      experiment, dataset)
-# pylint: disable=unused-import
-from qcodes.tests.dataset.test_dependencies import some_interdeps
 
 
 @pytest.mark.usefixtures("experiment")
